@@ -9,27 +9,26 @@ slackget10 - The great new slackget10!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
+slack-get (http://slackget.infinityperl.org) is an apt-get like tool for Slackware Linux. This bundle is the core library of this program.
 
-Perhaps a little code snippet.
+The name slackget10 means slack-get 1.0 because this module is complely new and is for the 1.0 release. It is entierely object oriented, and require some other modules (like XML::Simple, Net::Ftp and LWP::Simple).
+
+This module is still pre-in alpha development phase and I release it on CPAN only for coder which want to see the new archtecture. For more informations, have a look on subclasses.
 
     use slackget10;
 
     my $foo = slackget10->new();
     ...
 
-=head1 EXPORT
-
-A list of functions that can be exported.  You can delete this section
-if you don't export anything, such as for a purely object-oriented module.
+=head1 CONSTRUCTOR
 
 =head1 FUNCTIONS
 
